
/* Generated data (by pika-mkenums) */

#include "stamp-pikawidgetsenums.h"
#include "config.h"
#include <gio/gio.h>
#include "libpikabase/pikabase.h"
#include "pikawidgetsenums.h"
#include "libpika/libpika-intl.h"

/* enumerations from "pikawidgetsenums.h" */
GType
pika_aspect_type_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_ASPECT_SQUARE, "PIKA_ASPECT_SQUARE", "square" },
    { PIKA_ASPECT_PORTRAIT, "PIKA_ASPECT_PORTRAIT", "portrait" },
    { PIKA_ASPECT_LANDSCAPE, "PIKA_ASPECT_LANDSCAPE", "landscape" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_ASPECT_SQUARE, NC_("aspect-type", "Square"), NULL },
    { PIKA_ASPECT_PORTRAIT, NC_("aspect-type", "Portrait"), NULL },
    { PIKA_ASPECT_LANDSCAPE, NC_("aspect-type", "Landscape"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaAspectType", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "aspect-type");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_chain_position_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_CHAIN_TOP, "PIKA_CHAIN_TOP", "top" },
    { PIKA_CHAIN_LEFT, "PIKA_CHAIN_LEFT", "left" },
    { PIKA_CHAIN_BOTTOM, "PIKA_CHAIN_BOTTOM", "bottom" },
    { PIKA_CHAIN_RIGHT, "PIKA_CHAIN_RIGHT", "right" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_CHAIN_TOP, "PIKA_CHAIN_TOP", NULL },
    { PIKA_CHAIN_LEFT, "PIKA_CHAIN_LEFT", NULL },
    { PIKA_CHAIN_BOTTOM, "PIKA_CHAIN_BOTTOM", NULL },
    { PIKA_CHAIN_RIGHT, "PIKA_CHAIN_RIGHT", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaChainPosition", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "chain-position");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_color_area_type_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_COLOR_AREA_FLAT, "PIKA_COLOR_AREA_FLAT", "flat" },
    { PIKA_COLOR_AREA_SMALL_CHECKS, "PIKA_COLOR_AREA_SMALL_CHECKS", "small-checks" },
    { PIKA_COLOR_AREA_LARGE_CHECKS, "PIKA_COLOR_AREA_LARGE_CHECKS", "large-checks" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_COLOR_AREA_FLAT, "PIKA_COLOR_AREA_FLAT", NULL },
    { PIKA_COLOR_AREA_SMALL_CHECKS, "PIKA_COLOR_AREA_SMALL_CHECKS", NULL },
    { PIKA_COLOR_AREA_LARGE_CHECKS, "PIKA_COLOR_AREA_LARGE_CHECKS", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaColorAreaType", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "color-area-type");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_color_selector_channel_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_COLOR_SELECTOR_HUE, "PIKA_COLOR_SELECTOR_HUE", "hue" },
    { PIKA_COLOR_SELECTOR_SATURATION, "PIKA_COLOR_SELECTOR_SATURATION", "saturation" },
    { PIKA_COLOR_SELECTOR_VALUE, "PIKA_COLOR_SELECTOR_VALUE", "value" },
    { PIKA_COLOR_SELECTOR_RED, "PIKA_COLOR_SELECTOR_RED", "red" },
    { PIKA_COLOR_SELECTOR_GREEN, "PIKA_COLOR_SELECTOR_GREEN", "green" },
    { PIKA_COLOR_SELECTOR_BLUE, "PIKA_COLOR_SELECTOR_BLUE", "blue" },
    { PIKA_COLOR_SELECTOR_ALPHA, "PIKA_COLOR_SELECTOR_ALPHA", "alpha" },
    { PIKA_COLOR_SELECTOR_LCH_LIGHTNESS, "PIKA_COLOR_SELECTOR_LCH_LIGHTNESS", "lch-lightness" },
    { PIKA_COLOR_SELECTOR_LCH_CHROMA, "PIKA_COLOR_SELECTOR_LCH_CHROMA", "lch-chroma" },
    { PIKA_COLOR_SELECTOR_LCH_HUE, "PIKA_COLOR_SELECTOR_LCH_HUE", "lch-hue" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_COLOR_SELECTOR_HUE, NC_("color-selector-channel", "_H"), N_("HSV Hue") },
    { PIKA_COLOR_SELECTOR_SATURATION, NC_("color-selector-channel", "_S"), N_("HSV Saturation") },
    { PIKA_COLOR_SELECTOR_VALUE, NC_("color-selector-channel", "_V"), N_("HSV Value") },
    { PIKA_COLOR_SELECTOR_RED, NC_("color-selector-channel", "_R"), N_("Red") },
    { PIKA_COLOR_SELECTOR_GREEN, NC_("color-selector-channel", "_G"), N_("Green") },
    { PIKA_COLOR_SELECTOR_BLUE, NC_("color-selector-channel", "_B"), N_("Blue") },
    { PIKA_COLOR_SELECTOR_ALPHA, NC_("color-selector-channel", "_A"), N_("Alpha") },
    { PIKA_COLOR_SELECTOR_LCH_LIGHTNESS, NC_("color-selector-channel", "_L"), N_("LCh Lightness") },
    { PIKA_COLOR_SELECTOR_LCH_CHROMA, NC_("color-selector-channel", "_C"), N_("LCh Chroma") },
    { PIKA_COLOR_SELECTOR_LCH_HUE, NC_("color-selector-channel", "_h"), N_("LCh Hue") },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaColorSelectorChannel", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "color-selector-channel");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_color_selector_model_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_COLOR_SELECTOR_MODEL_RGB, "PIKA_COLOR_SELECTOR_MODEL_RGB", "rgb" },
    { PIKA_COLOR_SELECTOR_MODEL_LCH, "PIKA_COLOR_SELECTOR_MODEL_LCH", "lch" },
    { PIKA_COLOR_SELECTOR_MODEL_HSV, "PIKA_COLOR_SELECTOR_MODEL_HSV", "hsv" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_COLOR_SELECTOR_MODEL_RGB, NC_("color-selector-model", "RGB"), N_("RGB color model") },
    { PIKA_COLOR_SELECTOR_MODEL_LCH, NC_("color-selector-model", "LCH"), N_("CIE LCh color model") },
    { PIKA_COLOR_SELECTOR_MODEL_HSV, NC_("color-selector-model", "HSV"), N_("HSV color model") },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaColorSelectorModel", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "color-selector-model");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_int_combo_box_layout_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_INT_COMBO_BOX_LAYOUT_ICON_ONLY, "PIKA_INT_COMBO_BOX_LAYOUT_ICON_ONLY", "icon-only" },
    { PIKA_INT_COMBO_BOX_LAYOUT_ABBREVIATED, "PIKA_INT_COMBO_BOX_LAYOUT_ABBREVIATED", "abbreviated" },
    { PIKA_INT_COMBO_BOX_LAYOUT_FULL, "PIKA_INT_COMBO_BOX_LAYOUT_FULL", "full" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_INT_COMBO_BOX_LAYOUT_ICON_ONLY, "PIKA_INT_COMBO_BOX_LAYOUT_ICON_ONLY", NULL },
    { PIKA_INT_COMBO_BOX_LAYOUT_ABBREVIATED, "PIKA_INT_COMBO_BOX_LAYOUT_ABBREVIATED", NULL },
    { PIKA_INT_COMBO_BOX_LAYOUT_FULL, "PIKA_INT_COMBO_BOX_LAYOUT_FULL", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaIntComboBoxLayout", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "int-combo-box-layout");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_page_selector_target_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_PAGE_SELECTOR_TARGET_LAYERS, "PIKA_PAGE_SELECTOR_TARGET_LAYERS", "layers" },
    { PIKA_PAGE_SELECTOR_TARGET_IMAGES, "PIKA_PAGE_SELECTOR_TARGET_IMAGES", "images" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_PAGE_SELECTOR_TARGET_LAYERS, NC_("page-selector-target", "Layers"), NULL },
    { PIKA_PAGE_SELECTOR_TARGET_IMAGES, NC_("page-selector-target", "Images"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaPageSelectorTarget", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "page-selector-target");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_size_entry_update_policy_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_SIZE_ENTRY_UPDATE_NONE, "PIKA_SIZE_ENTRY_UPDATE_NONE", "none" },
    { PIKA_SIZE_ENTRY_UPDATE_SIZE, "PIKA_SIZE_ENTRY_UPDATE_SIZE", "size" },
    { PIKA_SIZE_ENTRY_UPDATE_RESOLUTION, "PIKA_SIZE_ENTRY_UPDATE_RESOLUTION", "resolution" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_SIZE_ENTRY_UPDATE_NONE, "PIKA_SIZE_ENTRY_UPDATE_NONE", NULL },
    { PIKA_SIZE_ENTRY_UPDATE_SIZE, "PIKA_SIZE_ENTRY_UPDATE_SIZE", NULL },
    { PIKA_SIZE_ENTRY_UPDATE_RESOLUTION, "PIKA_SIZE_ENTRY_UPDATE_RESOLUTION", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaSizeEntryUpdatePolicy", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "size-entry-update-policy");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_zoom_type_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_ZOOM_IN, "PIKA_ZOOM_IN", "in" },
    { PIKA_ZOOM_OUT, "PIKA_ZOOM_OUT", "out" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_ZOOM_IN, NC_("zoom-type", "Zoom in"), NULL },
    { PIKA_ZOOM_OUT, NC_("zoom-type", "Zoom out"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaZoomType", values);
      pika_type_set_translation_domain (type, GETTEXT_PACKAGE "-libpika");
      pika_type_set_translation_context (type, "zoom-type");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}


/* Generated data ends here */

